==> Dressing_1.0.0.202504111928-20.jar: src/dressing/ui/modelprovders/DimHLabelProvider.java <==
package dressing.ui.modelprovders;

import java.math.RoundingMode;
import java.text.DecimalFormat;
import java.text.DecimalFormatSymbols;
import java.util.Locale;

import org.eclipse.jface.viewers.LabelProvider;
import org.eclipse.jface.viewers.StyledString;
import org.eclipse.jface.viewers.DelegatingStyledCellLabelProvider.IStyledLabelProvider;

import dressing.model.DesignObject3D;
import dressing.model.Piece2D;
import dressing.model.usinage.Usinage;

public class DimHLabelProvider extends LabelProvider implements IStyledLabelProvider {

    @Override
    public StyledString getStyledText(Object element) {
        if (element!=null && element instanceof Piece2D) {
        	Piece2D piece = (Piece2D) element;

        	DecimalFormat formatter = new DecimalFormat("#.0", DecimalFormatSymbols.getInstance( Locale.ENGLISH ));
        	formatter.setRoundingMode( RoundingMode.HALF_UP );
        	String s = formatter.format(piece.getPieceH());
                // a directory is just a container and has no size
                return new StyledString(s);
        }else if(element !=null && element instanceof DesignObject3D && !(element instanceof Usinage))  {
        	DesignObject3D piece = (DesignObject3D) element;

        	DecimalFormat formatter = new DecimalFormat("#.0", DecimalFormatSymbols.getInstance( Locale.ENGLISH ));
        	formatter.setRoundingMode( RoundingMode.HALF_UP );
        	String s = formatter.format(piece.getHauteurext());
                // a directory is just a container and has no size
                return new StyledString(s);
        }
        return new StyledString(" ");
    }
    
}

==> Dressing_1.0.0.202512261028-1210.jar: src/dressing/ui/modelprovders/DimHLabelProvider.java <==
package dressing.ui.modelprovders;

import java.math.RoundingMode;
import java.text.DecimalFormat;
import java.text.DecimalFormatSymbols;
import java.util.Locale;

import org.eclipse.jface.viewers.LabelProvider;
import org.eclipse.jface.viewers.StyledString;
import org.eclipse.jface.viewers.DelegatingStyledCellLabelProvider.IStyledLabelProvider;

import dressing.model.DesignObject3D;
import dressing.model.Piece2D;
import dressing.model.Usinage;

public class DimHLabelProvider extends LabelProvider implements IStyledLabelProvider {

    @Override
    public StyledString getStyledText(Object element) {
        if (element!=null && element instanceof Piece2D) {
        	Piece2D piece = (Piece2D) element;

        	DecimalFormat formatter = new DecimalFormat("#.0", DecimalFormatSymbols.getInstance( Locale.ENGLISH ));
        	formatter.setRoundingMode( RoundingMode.HALF_UP );
        	String s = formatter.format(piece.getPieceH());
                // a directory is just a container and has no size
                return new StyledString(s);
        }else if(element !=null && element instanceof DesignObject3D && !(element instanceof Usinage))  {
        	DesignObject3D piece = (DesignObject3D) element;

        	DecimalFormat formatter = new DecimalFormat("#.0", DecimalFormatSymbols.getInstance( Locale.ENGLISH ));
        	formatter.setRoundingMode( RoundingMode.HALF_UP );
        	String s = formatter.format(piece.getHauteurext());
                // a directory is just a container and has no size
                return new StyledString(s);
        }
        return new StyledString(" ");
    }
    
}
